@@ -1,21 +1,7 @@
 /*
-    Copyright 2010 Rafael Fernández López <ereslibre@kde.org>
+    SPDX-FileCopyrightText: 2010 Rafael Fernández López <ereslibre@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library. If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "udevmanager.h"
@@ -85,7 +71,9 @@ bool UDevManager::Private::checkOfInterest(const UdevQt::Device &device)
     qDebug() << "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<";
     qDebug() << "Path:" << device.sysfsPath();
     qDebug() << "Properties:" << device.deviceProperties();
-    Q_FOREACH (const QString &key, device.deviceProperties()) {
+
+    const QStringList properties = device.deviceProperties();
+    for (const QString &key : properties) {
         qDebug() << "\t" << key << ":" << device.deviceProperty(key).toString();
     }
     qDebug() << "Driver:" << device.driver();
@@ -164,7 +152,7 @@ QStringList UDevManager::allDevices()
 {
     QStringList res;
     const UdevQt::DeviceList deviceList = d->m_client->allDevices();
-    Q_FOREACH (const UdevQt::Device &device, deviceList) {
+    for (const UdevQt::Device &device : deviceList) {
         if (d->isOfInterest(udiPrefix() + device.sysfsPath(), device)) {
             res << udiPrefix() + device.sysfsPath();
         }
