@@ -1,22 +1,8 @@
 /*
-    Copyright 2009 Pino Toscano <pino@kde.org>
-    Copyright 2009-2012 Lukáš Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2009 Pino Toscano <pino@kde.org>
+    SPDX-FileCopyrightText: 2009-2012 Lukáš Tinkl <ltinkl@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library. If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "udisksstorageaccess.h"
@@ -26,8 +12,9 @@
 #include <QDomDocument>
 #include <QDBusConnection>
 #include <QDir>
-#include <QApplication>
-#include <QWidget>
+#include <QDBusInterface>
+#include <QGuiApplication>
+#include <QWindow>
 
 using namespace Solid::Backends::UDisks2;
 
@@ -161,7 +148,6 @@ void StorageAccess::checkAccessibility()
 
 void StorageAccess::slotDBusReply(const QDBusMessage & /*reply*/)
 {
-    const QString ctPath = clearTextPath();
     if (m_setupInProgress) {
         if (isLuksDevice() && !isAccessible()) { // unlocked device, now mount it
             mount();
@@ -173,6 +159,7 @@ void StorageAccess::slotDBusReply(const QDBusMessage & /*reply*/)
             checkAccessibility();
         }
     } else if (m_teardownInProgress) { // FIXME
+        const QString ctPath = clearTextPath();
         qCDebug(UDISKS2) << "Successfully unmounted " << m_device->udi();
         if (isLuksDevice() && !ctPath.isEmpty() && ctPath != "/") { // unlocked device, lock it
             callCryptoTeardown();
@@ -185,7 +172,7 @@ void StorageAccess::slotDBusReply(const QDBusMessage & /*reply*/)
                 Device drive(drivePath);
                 QDBusConnection c = QDBusConnection::systemBus();
 
-                if (drive.prop("Ejectable").toBool() &&
+                if (drive.prop("MediaRemovable").toBool() &&
                         drive.prop("MediaAvailable").toBool() &&
                         !m_device->isOpticalDisc()) { // optical drives have their Eject method
                     QDBusMessage msg = QDBusMessage::createMethodCall(UD2_DBUS_SERVICE, drivePath, UD2_DBUS_INTERFACE_DRIVE, "Eject");
@@ -258,10 +245,12 @@ void StorageAccess::slotTeardownDone(int error, const QString &errorString)
 bool StorageAccess::mount()
 {
     QString path = m_device->udi();
-    const QString ctPath = clearTextPath();
 
-    if (isLuksDevice() && !ctPath.isEmpty()) { // mount options for the cleartext volume
-        path = ctPath;
+    if (isLuksDevice()) { // mount options for the cleartext volume
+        const QString ctPath = clearTextPath();
+        if (!ctPath.isEmpty()) {
+            path = ctPath;
+        }
     }
 
     QDBusConnection c = QDBusConnection::systemBus();
@@ -282,10 +271,12 @@ bool StorageAccess::mount()
 bool StorageAccess::unmount()
 {
     QString path = m_device->udi();
-    const QString ctPath = clearTextPath();
 
-    if (isLuksDevice() && !ctPath.isEmpty()) { // unmount options for the cleartext volume
-        path = ctPath;
+    if (isLuksDevice()) { // unmount options for the cleartext volume
+        const QString ctPath = clearTextPath();
+        if (!ctPath.isEmpty()) {
+            path = ctPath;
+        }
     }
 
     QDBusConnection c = QDBusConnection::systemBus();
@@ -302,7 +293,7 @@ bool StorageAccess::unmount()
 
 QString StorageAccess::generateReturnObjectPath()
 {
-    static int number = 1;
+    static QAtomicInt number = 1;
 
     return "/org/kde/solid/UDisks2StorageAccess_" + QString::number(number++);
 }
@@ -344,7 +335,9 @@ bool StorageAccess::requestPassphrase()
 
     QDBusConnection::sessionBus().registerObject(m_lastReturnObject, this, QDBusConnection::ExportScriptableSlots);
 
-    QWidget *activeWindow = QApplication::activeWindow();
+    // TODO: this only works on X11, Wayland doesn't have global window ids.
+    // Passing ids to other processes doesn't make any sense
+    auto activeWindow = QGuiApplication::focusWindow();
     uint wId = 0;
     if (activeWindow != nullptr) {
         wId = (uint)activeWindow->winId();
